@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -94,7 +94,7 @@ void GrantleeThemeTest::shouldLoadTheme()
     QFETCH(bool, isvalid);
     QFETCH(QStringList, displayExtraVariables);
 
-    GrantleeTheme::Theme theme(QStringLiteral(GRANTLEETHEME_DATA_DIR) + QDir::separator() + dirname, dirname, filename);
+    GrantleeTheme::Theme theme(QStringLiteral(GRANTLEETHEME_DATA_DIR "/themes/")  + dirname, dirname, filename);
     QCOMPARE(theme.isValid(), isvalid);
     QCOMPARE(theme.displayExtraVariables(), displayExtraVariables);
     QCOMPARE(theme.dirName(), dirname);
@@ -182,7 +182,7 @@ void GrantleeThemeTest::testRenderTemplate()
     QFETCH(QString, filename);
     QFETCH(QString, templateBasename);
 
-    const QString themePath = QStringLiteral(GRANTLEETHEME_DATA_DIR) + QDir::separator() + dirname;
+    const QString themePath = QStringLiteral(GRANTLEETHEME_DATA_DIR "/themes/") + dirname;
 
     QVariantHash data;
     data[QStringLiteral("icon")] = QStringLiteral("kde");
@@ -205,4 +205,4 @@ void GrantleeThemeTest::testRenderTemplate()
     }
 }
 
-QTEST_MAIN(GrantleeThemeTest)
+QTEST_GUILESS_MAIN(GrantleeThemeTest)
